
# Description
UNS_PROJECTS contains a collection of unsio based programs

# Requirements
- you need to install CMAKE utility (Cf http://www.cmake.org/)
- unsio library must be installed (see http://projets.lam.fr/projects/unsio/wiki)

# Compilation
mkdir build  
cd build   
cmake ..  
make  

# Installation
make install

# Python Wrapper
There is a python wrapper, see py/README.md in the source directory, or visit https://pypi.org/project/python-unsiotools/

# Licence
CeCILL2 (http://www.cecill.info/licences/Licence_CeCILL_V2-en.txt)

# Copyright
**Copyright Jean-Charles LAMBERT**     
**Jean-Charles.Lambert_at_lam.fr**     

address:  
Dynamique des galaxies   
Centre de donneeS Astrophysique de Marseille (CeSAM)   
Laboratoire d'Astrophysique de Marseille   
Pole de l'Etoile, site de Chateau-Gombert    
38, rue Frederic Joliot-Curie   
13388 Marseille cedex 13 France   
CNRS U.M.R 7326   
